@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: boot.h,v 1.20 2005/10/06 20:00:37 aesok Exp $ */
+/* $Id: boot.h,v 1.20.2.1 2006/01/22 19:35:30 joerg_wunsch Exp $ */
 
 #ifndef _AVR_BOOT_H_
 #define _AVR_BOOT_H_    1
@@ -559,7 +559,7 @@
 #define boot_rww_enable()             __boot_rww_enable_alternate()
 #define boot_lock_bits_set(lock_bits) __boot_lock_bits_set_alternate(lock_bits)
 
-#elif (FLASHEND > USHRT_MAX) && !defined(__USING_MINT8)
+#elif (FLASHEND > USHRT_MAX) && (__USING_MINT8)
 
 /* Extended: >16 bit address */
 #define boot_page_fill(address, data) __boot_page_fill_extended(address, data)
