@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: eeprom.h,v 1.11.2.5 2005/09/08 13:50:21 aesok Exp $ */
+/* $Id: eeprom.h,v 1.17 2005/09/13 13:29:54 joerg_wunsch Exp $ */
 
 /*
    eeprom.h
@@ -84,7 +84,7 @@
 #endif
 
 
-/** \defgroup avr_eeprom EEPROM handling
+/** \defgroup avr_eeprom <avr/eeprom.h>: EEPROM handling
     \code #include <avr/eeprom.h> \endcode
 
     This header file declares the interface to some simple library
@@ -160,7 +160,7 @@ eeprom_write_block (const void *pointer_ram,
     \ingroup avr_eeprom
     \returns 1 if EEPROM is ready for a new read/write operation, 0 if not. */
 
-#if defined(DOXYGEN)
+#if defined(__DOXYGEN__)
 # define eeprom_is_ready()
 #elif defined(EEWE)
 # define eeprom_is_ready() bit_is_clear(EECR, EEWE)
