@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io2323.h,v 1.5.2.1 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: io2323.h,v 1.8 2005/10/30 22:11:23 joerg_wunsch Exp $ */
 
 /* avr/io2323.h - definitions for AT90S2323 */
 
@@ -101,8 +101,13 @@
 
 /* Interrupt vectors */
 
-#define SIG_INTERRUPT0		_VECTOR(1)
-#define SIG_OVERFLOW0		_VECTOR(2)
+/* External Interrupt 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF0_vect		_VECTOR(2)
+#define SIG_OVERFLOW0			_VECTOR(2)
 
 #define _VECTORS_SIZE 6
 
