@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: setjmp.h,v 1.6.2.1 2005/01/16 18:27:52 joerg_wunsch Exp $ */
+/* $Id: setjmp.h,v 1.9 2005/09/13 13:29:54 joerg_wunsch Exp $ */
 
 #ifndef __SETJMP_H_
 #define __SETJMP_H_ 1
@@ -48,14 +48,14 @@ extern "C" {
 	24 = total size
  */
 
-#if !defined(DOXYGEN)
+#if !defined(__DOXYGEN__)
 
 #define _JBLEN 24
 typedef struct _jmp_buf { unsigned char _jb[_JBLEN + 1]; } jmp_buf[1];
 
-#endif /* not DOXYGEN */
+#endif /* not __DOXYGEN__ */
 
-/** \defgroup setjmp Setjmp and Longjmp
+/** \defgroup setjmp <setjmp.h>: Non-local goto
 
     While the C language has the dreaded \c goto statement, it can only be
     used to jump to a label in the same (local) function.  In order to jump
